@@ -7,6 +7,7 @@
  */
 
 #include "addlocationmodel.h"
+#include "about.h"
 #include "alarm.h"
 #include "alarmmodel.h"
 #include "kclockformat.h"
@@ -47,10 +48,16 @@ QCommandLineParser *createParser()
 
 int main(int argc, char *argv[])
 {
-    QApplication app(argc, argv);
+    // set default style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
+    // if using org.kde.desktop, ensure we use kde style if possible
+    if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORMTHEME")) {
+        qputenv("QT_QPA_PLATFORMTHEME", "kde");
+    }
+
+    QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kclock");
     KAboutData aboutData(QStringLiteral("kclock"),
@@ -58,12 +65,14 @@ int main(int argc, char *argv[])
                          QStringLiteral(KCLOCK_VERSION_STRING),
                          QStringLiteral("Set alarms and timers, use a stopwatch, and manage world clocks"),
                          KAboutLicense::GPL,
-                         i18n("© 2020-2021 KDE Community"));
+                         i18n("© 2020-2022 KDE Community"));
     aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/kclock/-/issues");
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     KAboutData::setApplicationData(aboutData);
 
+    // ~~~~ DBus setup ~~~~
+
     // ensure kclockd is up with dbus autostart, any call will do
     QDBusInterface *testInterface = new QDBusInterface(QStringLiteral("org.kde.kclockd"),
                                                        QStringLiteral("/Alarms"),
@@ -73,6 +82,15 @@ int main(int argc, char *argv[])
     testInterface->call(QStringLiteral("Introspect"));
     testInterface->deleteLater();
 
+    OrgKdePowerManagementInterface *interface =
+        new OrgKdePowerManagementInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Utility"), QDBusConnection::sessionBus());
+    interface->keepAlive();
+    QObject::connect(&app, &QCoreApplication::aboutToQuit, &app, [interface] {
+        interface->canExit();
+    });
+
+    // ~~~ Qt application setup ~~~~
+
     // initialize models
     auto *stopwatchTimer = new StopwatchTimer();
     auto *weekModel = new WeekModel();
@@ -93,21 +111,33 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TimerModel::instance();
     });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "AlarmModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return AlarmModel::instance();
+    });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "UtilModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return UtilModel::instance();
+    });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "StopwatchTimer", [stopwatchTimer](QQmlEngine *, QJSEngine *) -> QObject * {
+        return stopwatchTimer;
+    });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "KClockFormat", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return KclockFormat::instance();
+    });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "WeekModel", [weekModel](QQmlEngine *, QJSEngine *) -> QObject * {
+        return weekModel;
+    });
+    qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "SettingsModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return SettingsModel::instance();
+    });
+    qmlRegisterSingletonInstance("kclock", 1, 0, "AboutType", &AboutType::instance());
 
     QQmlApplicationEngine *engine = new QQmlApplicationEngine();
 
     engine->rootContext()->setContextObject(new KLocalizedContext(engine));
-    // models
-    engine->rootContext()->setContextProperty(QStringLiteral("alarmModel"), AlarmModel::instance());
-    engine->rootContext()->setContextProperty(QStringLiteral("utilModel"), UtilModel::instance());
-    engine->rootContext()->setContextProperty(QStringLiteral("stopwatchTimer"), stopwatchTimer);
-    engine->rootContext()->setContextProperty(QStringLiteral("kclockFormat"), KclockFormat::instance());
-    engine->rootContext()->setContextProperty(QStringLiteral("weekModel"), weekModel);
-    engine->rootContext()->setContextProperty(QStringLiteral("settingsModel"), SettingsModel::instance());
-    engine->rootContext()->setContextProperty(QStringLiteral("kclockAboutData"), QVariant::fromValue(aboutData));
 
     engine->load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
+    // ~~~~ Parse command line arguments ~~~~
     {
         QScopedPointer<QCommandLineParser> parser(createParser());
         parser->process(app);
@@ -121,11 +151,5 @@ int main(int argc, char *argv[])
         }
     }
 
-    OrgKdePowerManagementInterface *interface =
-        new OrgKdePowerManagementInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Utility"), QDBusConnection::sessionBus());
-    interface->keepAlive();
-    QObject::connect(&app, &QCoreApplication::aboutToQuit, &app, [interface] {
-        interface->canExit();
-    });
     return app.exec();
 }
